@@ -10,7 +10,7 @@
       
       # check if R is positive definite
       eigenR <- eigen(R)$values
-      if(max(abs(R[lower.tri(R)]))>1.0||min(eigenR)<0||!is.real(eigenR)){
+      if(max(abs(R[lower.tri(R)]))>1.0||min(eigenR)<0||!is.double(eigenR)){
          R <- diag(ndim)
       }
       h <- vector.garch(dvar, a, A, B)
