@@ -2,5 +2,5 @@
 
    vector.garch <- function(dvar, a, A, B){
       dvar <- dvar^2           # dvar = eps
-     .Call(vector_garch, dvar, a, A, B)
+     .Call("vector_garch", dvar, a, A, B)
    }
